@@ -34,7 +34,7 @@ class ResultType(_ResultType):
         if cls is Ok or issubclass(cls, Ok):
             V = key
 
-            if not isinstance(V, type):
+            if not (isinstance(V, (type, ForwardRef, str)) or V in (Any,)):
                 raise TypeError(f'Type {V} sould be instance of type')
 
             T: ResultType = type(
@@ -45,7 +45,7 @@ class ResultType(_ResultType):
         elif cls is Err or issubclass(cls, Err):
             E = key
 
-            if not isinstance(E, type):
+            if not (isinstance(E, (type, ForwardRef, str)) or E in (Any,)):
                 raise TypeError(f'Type {E} sould be instance of type')
 
             T: ResultType = type(
@@ -62,16 +62,16 @@ class ResultType(_ResultType):
                     V, E = key
                 else:
                     raise TypeError(f'Type {key} sould be instance of type or tuple[type, type]')
-            elif isinstance(key, type):
+            elif isinstance(key, (type, ForwardRef, str)) or key in (Any,):
                 V = key
                 E = Exception
             else:
                 raise TypeError(f'Type {key} sould be instance of type or tuple[type, type]')
 
-            if not isinstance(V, type):
+            if not (isinstance(V, (type, ForwardRef, str)) or V in (Any,)):
                 raise TypeError(f'Type {V} sould be instance of type')
 
-            if not isinstance(E, type):
+            if not (isinstance(E, (type, ForwardRef, str)) or E in (Any,)):
                 raise TypeError(f'Type {E} sould be instance of type')
 
             T: ResultType = type(
@@ -89,10 +89,10 @@ class ResultType(_ResultType):
         V: type = cls.__annotations__['v']
         E: type = other.__annotations__['e']
 
-        if not isinstance(V, type):
+        if not (isinstance(V, (type, ForwardRef, str)) or V in (Any,)):
             raise TypeError(f'Type {V} sould be instance of type')
 
-        if not isinstance(E, type):
+        if not (isinstance(E, (type, ForwardRef, str)) or E in (Any,)):
             raise TypeError(f'Type {E} sould be instance of type')
 
         T: ResultType = type(
@@ -123,10 +123,10 @@ class ResultType(_ResultType):
             V: type = cls.__annotations__.get('v', fn.__annotations__.get('return', Any))
             E: type = cls.__annotations__.get('e', Exception)
 
-            if not isinstance(V, type):
+            if not (isinstance(V, (type, ForwardRef, str)) or V in (Any,)):
                 raise TypeError(f'Type {V} sould be instance of type')
 
-            if not isinstance(E, type):
+            if not (isinstance(E, (type, ForwardRef, str)) or E in (Any,)):
                 raise TypeError(f'Type {E} sould be instance of type')
             
             if asyncio.iscoroutinefunction(fn):
